==> agrosyst-web-0.11-sources.jar: fr/inra/agrosyst/web/actions/growingsystems/GrowingSystemEditJson.java <==
package fr.inra.agrosyst.web.actions.growingsystems;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GrowingSystemEditJson.java 3515 2014-02-26 21:00:13Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-0.11/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/growingsystems/GrowingSystemEditJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.NavigationContext;
import fr.inra.agrosyst.api.services.growingplan.GrowingPlanService;
import fr.inra.agrosyst.api.services.growingsystem.GrowingSystemService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;
import org.apache.struts2.convention.annotation.Action;

/**
 * Created by davidcosse on 25/02/14.
 */
public class GrowingSystemEditJson extends AbstractJsonAction {

    protected GrowingSystemService growingSystemService;

    protected String practicedSystemId;

    protected Object jsonData;

    public void setPracticedSystemId(String practicedSystemId) {
        this.practicedSystemId = practicedSystemId;
    }

    public void setGrowingSystemService(GrowingSystemService growingSystemService) {
        this.growingSystemService = growingSystemService;
    }

    @Action("available-growing-system-for-duplication-json")
    public String availableGrowingSystemsForDuplication() {
        NavigationContext navigationContext = getNavigationContext();
        jsonData = growingSystemService.getAvailableGsForDuplication(practicedSystemId, navigationContext);
        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        return jsonData;
    }
}

==> agrosyst-web-1.0.3-sources.jar: fr/inra/agrosyst/web/actions/growingsystems/GrowingSystemEditJson.java <==
package fr.inra.agrosyst.web.actions.growingsystems;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GrowingSystemEditJson.java 3564 2014-03-03 13:02:17Z echatellier $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.0.3/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/growingsystems/GrowingSystemEditJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.NavigationContext;
import fr.inra.agrosyst.api.services.growingsystem.GrowingSystemService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;
import org.apache.struts2.convention.annotation.Action;

/**
 * Created by davidcosse on 25/02/14.
 */
public class GrowingSystemEditJson extends AbstractJsonAction {

    protected GrowingSystemService growingSystemService;

    protected String practicedSystemId;

    protected Object jsonData;

    public void setPracticedSystemId(String practicedSystemId) {
        this.practicedSystemId = practicedSystemId;
    }

    public void setGrowingSystemService(GrowingSystemService growingSystemService) {
        this.growingSystemService = growingSystemService;
    }

    @Action("available-growing-system-for-duplication-json")
    public String availableGrowingSystemsForDuplication() {
        NavigationContext navigationContext = getNavigationContext();
        jsonData = growingSystemService.getAvailableGsForDuplication(practicedSystemId, navigationContext);
        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        return jsonData;
    }
}
